@@ -27,11 +27,11 @@ Pg::Explain::Node - Class representing single node from query plan
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -161,11 +161,15 @@ Moose-called function (from within constructor) which checks if provided node ty
 
 sub BUILD {
     my $self = shift;
-    if ( $self->type =~ m{ \A (Seq \s Scan ) \s on \s (\S+) (?: \s+ (\S+) ) ? \z }xms ) {
+    if ( $self->type =~ m{ \A ( Seq \s Scan | Bitmap \s+ Heap \s+ Scan) \s on \s (\S+) (?: \s+ (\S+) ) ? \z }xms ) {
         $self->type( $1 );
         $self->scan_on( { 'table_name' => $2, } );
         $self->scan_on->{ 'table_alias' } = $3 if defined $3;
     }
+    elsif ( $self->type =~ m{ \A ( Bitmap \s+ Index \s+ Scan) \s on \s (\S+) \z }xms ) {
+        $self->type( $1 );
+        $self->scan_on( { 'index_name' => $2, } );
+    }
     elsif ( $self->type =~ m{ \A (Index \s Scan (?: \s Backward )? ) \s using \s (\S+) \s on \s (\S+) (?: \s+ (\S+) ) ? \z }xms ) {
         $self->type( $1 );
         $self->scan_on(
@@ -331,6 +335,7 @@ sub get_struct {
     $reply->{ 'type' }                   = $self->type                       if defined $self->type;
     $reply->{ 'scan_on' }                = clone( $self->scan_on )           if defined $self->scan_on;
     $reply->{ 'extra_info' }             = clone( $self->extra_info )        if defined $self->extra_info;
+    $reply->{ 'is_analyzed' }            = $self->is_analyzed;
 
     $reply->{ 'sub_nodes' } = [ map { $_->get_struct } @{ $self->sub_nodes } ] if defined $self->sub_nodes;
     $reply->{ 'initplans' } = [ map { $_->get_struct } @{ $self->initplans } ] if defined $self->initplans;
@@ -347,14 +352,14 @@ Method for getting total node time, summarized with times of all subnodes, subpl
 
 sub total_inclusive_time {
     my $self = shift;
-    return unless defined $self->actual_loops;
+    return unless $self->actual_loops;
     return unless defined $self->actual_time_last;
     return $self->actual_loops * $self->actual_time_last;
 }
 
 =head2 total_exclusive_time
 
-Method for getting total node time, without times of subnodes, subplans and initplans - which amounts to time PostgreSQL spent running this paricular node.
+Method for getting total node time, without times of subnodes - which amounts to time PostgreSQL spent running this paricular node.
 
 =cut
 
@@ -364,13 +369,25 @@ sub total_exclusive_time {
     my $time = $self->total_inclusive_time;
     return unless defined $time;
 
-    for my $node (map { @{ $_ } } grep { defined $_ } ( $self->sub_nodes, $self->initplans, $self->subplans ) ) {
+    for my $node (map { @{ $_ } } grep { defined $_ } ( $self->sub_nodes ) ) {
         $time -= $node->total_inclusive_time;
     }
 
     return $time;
 }
 
+=head2 is_analyzed
+
+Returns 1 if the explain node it represents was generated by EXPLAIN ANALYZE. 0 otherwise.
+
+=cut
+
+sub is_analyzed {
+    my $self = shift;
+
+    return defined $self->actual_loops ? 1 : 0;
+}
+
 =head1 AUTHOR
 
 hubert depesz lubaczewski, C<< <depesz at depesz.com> >>
